/******************************************************************************
 * 
 * Copyright 2012 - 2013 Vektor Software.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 *****************************************************************************/


package com.vektorsoft.demux.core.mva;

/**
 * <p>
 *  An implementation of {@link DMXView} interface which provides some common methods that can be used 
 * for view across all supported platforms. Clients should extend this class to gain access to functionality 
 * provided automatically by the framework.
 * </p>
 *
 * @author Vladimir Djurovic
 */
public abstract  class DMXAbstractView implements DMXView {

    /** Set of model data IDs used for this view. */
    protected String[] ids;
    
    /** Adapter instance this view is registered with. */
    protected DMXAdapter adapter;
    
    /**
     * Creates new instance.
     * 
     * @param adapter adapter instance related to this view
     * @param dataIds model data IDs
     */
    public DMXAbstractView(DMXAdapter adapter, String... dataIds){
        this.adapter = adapter;
         if(dataIds.length > 0){
            ids = new String[dataIds.length];
            System.arraycopy(dataIds, 0, ids, 0, dataIds.length);
        } else {
            ids = new String[0];
        }
    }
   
    /**
     * Returns this class name as view ID.
     * 
     * @return class name
     */
    @Override
    public String getViewId() {
        return getClass().getName();
    }

    /**
     * Returns empty string as parent view ID.
     * 
     * @return empty string
     */
    @Override
    public String getParentViewId() {
        return "";
    }

    /**
     * Returns <code>null</code> as view placement constraint.
     * 
     * @return null
     */
    @Override
    public Object viewPlacementConstraint() {
        return null;
    }

    /**
     * This method does nothing. Subclasses should override it to add 
     * child view correctly.
     * 
     * @param child child view
     */
    @Override
    public void addChildView(DMXView child) {
        
    }

    /**
     * Empty implementation. Subclasses should override this method for
     * actual logic.
     * 
     * @param id child view ID
     * @param state view state
     */
    @Override
    public void setViewActive(String id, boolean state) {
        // do nothing
    }
    
    
    /**
     * Returns set of data IDs. This method will call {@link #loadDataIds() } to get list 
     * of data IDs for this view.
     * 
     * @return set of data IDs
     */
    @Override
    public final String[] getViewDataIds() {
        return ids;
    }


}
