/******************************************************************************
 * 
 * Copyright 2012 - 2013 Vektor Software.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 *****************************************************************************/

package com.vektorsoft.demux.core.mva;

/**
 * <p>
 * Controller represents one piece of application logic that performs some operation. Think of it as
 *  <i>Controller</i> part of MVC pattern.
 * </p>
 * <p>
 * In general. controller is a link between View and Model parts of MVC. In most cases,
 *  controller performs one operation, but can contain arbitrary number of operations.
 *  The workflow of controller should be the following:
 * </p>
 * <ol>
 * <li>Controller is invoked by some user action</li>
 * <li>Controller performs some operation. In the course of operation,it can possibly modify the state of the model</li>
 * <li>After operation is complete, controller selects the view that should be displayed next</li>
 * </ol>
 * <p>
 * <code>DMXController</code> acts as a facade for specific controller types, such as event listeners.
 * </p>
 */
public interface DMXController {

	/**
	 * Name of the view that should be displayed after this controller terminates
         * it's operation.
	 * 
	 * @return name of the next view to display
	 */
	String getNextViewId();

	/**
	 * <p>
	 * Returns a mapping string for which this controller will be invoked. Mapping
         * depends on a context in which controller operates. For example, in Swing application, it
         *  can be component name, while in web application it can be an URL.
	 * </p>
         * 
         * @return a string to which this view is mapped
	 */
	String getMapping();

	 String[] getControllerData();
        
        /**
         * Execute action associated with this controller.
         * 
         * @param model model data local to this method call
         * @param params operation parameters
         * @throws ExecutionException if an error occurs during execution
         */
        void execute(DMXLocalModel model, Object... params) throws ExecutionException;

}
